globalVariables(
  c("ducotedechezswann",
    "alombredesjeunesfillesenfleurs", 
    "lecotedeguermantes", 
    "sodomeetgomorrhe", 
    "laprisonniere", 
    "albertinedisparue", 
    "letempretrouve", 
    "proust_char", 
    "books", 
    "sentence", 
    "stop_words_fr", 
    "full_list", 
    "vol", 
    "count", 
    "text", 
    ".", 
    "vec", 
    "text")
)